==> dde-shell_1.0.10.tar.xz: BUILD/panels/dock/translations/org.deepin.ds.dock_fi.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="fi">
<context>
    <name>main</name>
    <message>
        <location filename="../package/main.qml" line="162"/>
        <source>Indicator Style</source>
        <translation>Ilmaisimen tyyli</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="164"/>
        <source>Fashion Mode</source>
        <translation>Keskitetty</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="169"/>
        <source>Efficient Mode</source>
        <translation>Alavalikko</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="175"/>
        <source>Alignment</source>
        <translation>Tasaus</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="206"/>
        <source>Left</source>
        <translation>Vasen</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="194"/>
        <source>Position</source>
        <translation>Asema</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="179"/>
        <source>Align Left</source>
        <translation>Vasemmalle</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="181"/>
        <source>Align Top</source>
        <translation>Tasaa ylös</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="188"/>
        <source>Align Center</source>
        <translation>Tasaa keskelle</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="196"/>
        <source>Top</source>
        <translation>Ylös</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="201"/>
        <source>Bottom</source>
        <translation>Alas</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="211"/>
        <source>Right</source>
        <translation>Oikea</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="217"/>
        <source>Status</source>
        <translation>Tila</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="219"/>
        <source>Keep Shown</source>
        <translation>Näytä aina</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="224"/>
        <source>Keep Hidden</source>
        <translation>Piilotta paneeli</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="230"/>
        <source>Smart Hide</source>
        <translation>Älykäs piilotus</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="237"/>
        <source>Dock Settings</source>
        <translation>Paneeli asetukset</translation>
    </message>
</context>
</TS>

==> dde-shell_1.99.36.tar.xz: BUILD/panels/dock/translations/org.deepin.ds.dock_fi.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="fi">
<context>
    <name>main</name>
    <message>
        <source>Indicator Style</source>
        <translation>Ilmaisimen tyyli</translation>
    </message>
    <message>
        <source>Fashion Mode</source>
        <translation>Keskitetty</translation>
    </message>
    <message>
        <source>Efficient Mode</source>
        <translation>Alavalikko</translation>
    </message>
    <message>
        <source>Classic Mode</source>
        <translation>Klassinen</translation>
    </message>
    <message>
        <source>Centered Mode</source>
        <translation>Keskitetty</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Vasen</translation>
    </message>
    <message>
        <source>Position</source>
        <translation>Asema</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>Tila</translation>
    </message>
    <message>
        <source>Top</source>
        <translation>Ylös</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translation>Alas</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Oikea</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Tila</translation>
    </message>
    <message>
        <source>Keep Shown</source>
        <translation>Näytä aina</translation>
    </message>
    <message>
        <source>Keep Hidden</source>
        <translation>Piilotta paneeli</translation>
    </message>
    <message>
        <source>Smart Hide</source>
        <translation>Älykäs piilotus</translation>
    </message>
    <message>
        <source>Dock Settings</source>
        <translation>Paneeli asetukset</translation>
    </message>
</context>
</TS>
